Crate mung

Crate mung 

mung is a set of functions to demung or decode most common escapements used in data today

Functions

decode_entities
Decodes HTML/XML entities into their UTF-8 form
decode_rfc1738
Decodes URL character sequences that are percentage escaped (%25) into their UTF-8 form See: Uniform Resource Locators (URL) https://tools.ietf.org/html/rfc1738#section-2.2
decode_rfc2047
Decodes RFC 2047 encoded words into their UTF-8 form